import { Environment } from '@/environments/environment';
import { UIActionTool,Util } from '@/utils';
import UIService from '../ui-service';
import { Subject } from 'rxjs';
import OrmOrgService from '@/service/orm-org/orm-org-service';

/**
 * 组织管理UI服务对象基类
 *
 * @export
 * @class OrmOrgUIServiceBase
 */
export default class OrmOrgUIServiceBase extends UIService {

    /**
     * 是否支持工作流
     * 
     * @memberof  OrmOrgUIServiceBase
     */
    public isEnableWorkflow:boolean = false;

    /**
     * 当前UI服务对应的数据服务对象
     * 
     * @memberof  OrmOrgUIServiceBase
     */
    public dataService:OrmOrgService = new OrmOrgService();

    /**
     * 所有关联视图
     * 
     * @memberof  OrmOrgUIServiceBase
     */ 
    public allViewMap: Map<string, Object> = new Map();

    /**
     * 状态值
     * 
     * @memberof  OrmOrgUIServiceBase
     */ 
    public stateValue: number = 0;

    /**
     * 状态属性
     * 
     * @memberof  OrmOrgUIServiceBase
     */ 
    public stateField: string = "";

    /**
     * 主状态属性集合
     * 
     * @memberof  OrmOrgUIServiceBase
     */  
    public mainStateFields:Array<any> = [];

    /**
     * 主状态集合Map
     * 
     * @memberof  OrmOrgUIServiceBase
     */  
    public allDeMainStateMap:Map<string,string> = new Map();

    /**
     * Creates an instance of  OrmOrgUIServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  OrmOrgUIServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
        this.initViewMap();
        this.initDeMainStateMap();
    }

    /**
     * 初始化视图Map
     * 
     * @memberof  OrmOrgUIServiceBase
     */  
    public initViewMap(){
        this.allViewMap.set(':',{viewname:'xmbqpickupgridview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'qbzzpickupview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'sjyxzzpickupgridview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'orgtreeexpview',srfappde:'ormorgs'});
        this.allViewMap.set('MDATAVIEW:',{viewname:'gridview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'xmbqpickupview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'editview2',srfappde:'ormorgs'});
        this.allViewMap.set('EDITVIEW:',{viewname:'editview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'htgldwpickupview',srfappde:'ormorgs'});
        this.allViewMap.set('REDIRECTVIEW:',{viewname:'redirectview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'fpxxpickupview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'allleveltwoorgpickupview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'allsignorgorgpickupview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'jqgzsypickupgridview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'jqgzsyfpxxpickupview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'sjorgpickupview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'sjorgpickupgridview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'sjyxzzqxpickupview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'syzzpickupgridview',srfappde:'ormorgs'});
        this.allViewMap.set('MPICKUPVIEW:',{viewname:'mpickupview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'xjpickupview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'editview9_editmode',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'sjyxzzpickupview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'sjyxzzqxpickupgridview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'allleveltwoorgpickupgridview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'ypzsyfpxxpickupview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'allsignorgpickupgridview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'ypzxxsypickupgridview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'orgtreegridview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'pickupgridview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'xjpickupgridview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'fpxxpickupgridview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'suborggridview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'htgldwqpickupgridview',srfappde:'ormorgs'});
        this.allViewMap.set(':',{viewname:'editview9',srfappde:'ormorgs'});
        this.allViewMap.set('PICKUPVIEW:',{viewname:'pickupview',srfappde:'ormorgs'});
    }

    /**
     * 初始化主状态集合
     * 
     * @memberof  OrmOrgUIServiceBase
     */  
    public initDeMainStateMap(){
    }

    /**
     * 同步ERP组织信息
     *
     * @param {any[]} args 当前数据
     * @param {any} context 行为附加上下文
     * @param {*} [params] 附加参数
     * @param {*} [$event] 事件源
     * @param {*} [xData]  执行行为所需当前部件
     * @param {*} [actionContext]  执行行为上下文
     * @param {*} [srfParentDeName] 父实体名称
     * @returns {Promise<any>}
     */
    public async OrmOrg_SynOrg(args: any[],context:any = {}, params?: any, $event?: any, xData?: any,actionContext?: any,srfParentDeName?:string){
        let data: any = {};
        const _args: any[] = Util.deepCopy(args);
        const _this: any = actionContext;
        const actionTarget: string | null = 'NONE';
        context = UIActionTool.handleContextParam(actionTarget,_args,context);
        data = UIActionTool.handleActionParam(actionTarget,_args,params);
        context = Object.assign({},actionContext.context,context);
        let parentObj:any = {srfparentdename:srfParentDeName?srfParentDeName:null,srfparentkey:srfParentDeName?context[srfParentDeName.toLowerCase()]:null};
        Object.assign(data,parentObj);
        Object.assign(context,parentObj);
        // 直接调实体服务需要转换的数据
        if(context && context.srfsessionid){
          context.srfsessionkey = context.srfsessionid;
            delete context.srfsessionid;
        }
        const backend = () => {
            const curService:OrmOrgService =  new OrmOrgService();
            curService.SynOrg(context,data, true).then((response: any) => {
                if (!response || response.status !== 200) {
                    actionContext.$Notice.error({ title: '错误', desc: response.message });
                    return;
                }
                actionContext.$Notice.success({ title: '成功', desc: '手工从ERP系统中同步组织信息已完成！' });

                const _this: any = actionContext;
                if (xData && xData.refresh && xData.refresh instanceof Function) {
                    xData.refresh(args);
                }
                return response;
            }).catch((response: any) => {
                if (!response || !response.status || !response.data) {
                    actionContext.$Notice.error({ title: '错误', desc: '系统异常！' });
                    return;
                }
                if (response.status === 401) {
                    return;
                }
                return response;
            });
        };
        backend();
    }

    /**
     * 编辑
     *
     * @param {any[]} args 当前数据
     * @param {any} context 行为附加上下文
     * @param {*} [params] 附加参数
     * @param {*} [$event] 事件源
     * @param {*} [xData]  执行行为所需当前部件
     * @param {*} [actionContext]  执行行为上下文
     * @param {*} [srfParentDeName] 父实体名称
     * @returns {Promise<any>}
     */
    public async OrmOrg_OpenEditView(args: any[], context:any = {} ,params?: any, $event?: any, xData?: any,actionContext?:any,srfParentDeName?:string) {
        let data: any = {};
        const _args: any[] = Util.deepCopy(args);
        const _this: any = actionContext;
        const actionTarget: string | null = 'SINGLEKEY';
        Object.assign(context, { ormorg: '%ormorg%' });
        Object.assign(params, { orgid: '%ormorg%' });
        Object.assign(params, { orgname: '%orgname%' });
        context = UIActionTool.handleContextParam(actionTarget,_args,context);
        data = UIActionTool.handleActionParam(actionTarget,_args,params);
        context = Object.assign({},actionContext.context,context);
        let parentObj:any = {srfparentdename:srfParentDeName?srfParentDeName:null,srfparentkey:srfParentDeName?context[srfParentDeName.toLowerCase()]:null};
        Object.assign(data,parentObj);
        Object.assign(context,parentObj);
        let deResParameters: any[] = [];
        const parameters: any[] = [
            { pathName: 'ormorgs', parameterName: 'ormorg' },
        ];
            const openDrawer = (view: any, data: any) => {
                let container: Subject<any> = actionContext.$appdrawer.openDrawer(view, context,data);
                container.subscribe((result: any) => {
                    if (!result || !Object.is(result.ret, 'OK')) {
                        return;
                    }
                    const _this: any = actionContext;
                    if(window.opener){
                        window.opener.postMessage({status:'OK',identification:'WF'},Environment.uniteAddress);
                        window.close();
                    }
                    return result.datas;
                });
            }
            const view: any = {
                viewname: 'ormorgedit-view9-edit-mode', 
                height: 0, 
                width: 0,  
                title: actionContext.$t('entities.ormorg.views.editview9_editmode.title'),
                placement: 'DRAWER_TOP',
            };
            openDrawer(view, data);
    }


    /**
     * 获取指定数据的重定向页面
     * 
     * @param srfkey 数据主键
     * @param isEnableWorkflow  重定向视图是否需要处理流程中的数据
     * @memberof  OrmOrgUIServiceBase
     */
    public async getRDAppView(srfkey:string,isEnableWorkflow:boolean){
        this.isEnableWorkflow = isEnableWorkflow;
        // 进行数据查询
        let result:any = await this.dataService.Get({ormorg:srfkey});
        const curData:any = result.data;
        //判断当前数据模式,默认为true，todo
        const iRealDEModel:boolean = true;

        let bDataInWF:boolean = false;
		let bWFMode:any = false;
		// 计算数据模式
		if (this.isEnableWorkflow) {
			bDataInWF = await this.dataService.testDataInWF({stateValue:this.stateValue,stateField:this.stateField},curData);
			if (bDataInWF) {
				bDataInWF = true;
				bWFMode = await this.dataService.testUserExistWorklist(null,curData);
			}
        }
        let strPDTViewParam:string = await this.getDESDDEViewPDTParam(curData, bDataInWF, bWFMode);
        //若不是当前数据模式，处理strPDTViewParam，todo

        //查找视图

        //返回视图
        return this.allViewMap.get(strPDTViewParam);
    }

    /**
	 * 获取实际的数据类型
     * 
     * @memberof  OrmOrgUIServiceBase
	 */
	public getRealDEType(entity:any){

    }

    /**
     * 获取实体单数据实体视图预定义参数
     * 
     * @param curData 当前数据
     * @param bDataInWF 是否有数据在工作流中
     * @param bWFMode   是否工作流模式
     * @memberof  OrmOrgUIServiceBase
     */
    public async getDESDDEViewPDTParam(curData:any, bDataInWF:boolean, bWFMode:boolean){
        let strPDTParam:string = '';
		if (bDataInWF) {
			// 判断数据是否在流程中
        }
        //多表单，todo
        const isEnableMultiForm:boolean = false;
        const multiFormDEField:string|null =null;

        if (isEnableMultiForm && multiFormDEField) {
			const objFormValue:string = curData[multiFormDEField];
			if(!Environment.isAppMode){
				return 'MOBEDITVIEW'+objFormValue;
			}
			return 'EDITVIEW'+objFormValue;
        }
		if(!Environment.isAppMode){
            if(this.getDEMainStateTag(curData)){
                return `MOBEDITVIEW:MSTAG:${ await this.getDEMainStateTag(curData)}`;
            }
			return 'MOBEDITVIEW:';
        }
        if(this.getDEMainStateTag(curData)){
            return `EDITVIEW:MSTAG:${ await this.getDEMainStateTag(curData)}`;
        }
		return 'EDITVIEW:';
    }

    /**
     * 获取数据对象的主状态标识
     * 
     * @param curData 当前数据
     * @memberof  OrmOrgUIServiceBase
     */  
    public async getDEMainStateTag(curData:any){
        if(this.mainStateFields.length === 0) return null;

        this.mainStateFields.forEach((singleMainField:any) =>{
            if(!(singleMainField in curData)){
                console.error(`当前数据对象不包含属性singleMainField，可能会发生错误`);
            }
        })

        let strTag:String = "";
        for (let i = 0; i <= 1; i++) {
            let strTag:string = (curData[this.mainStateFields[0]])?(i == 0) ? curData[this.mainStateFields[0]] : "":"";
            if (this.mainStateFields.length >= 2) {
                for (let j = 0; j <= 1; j++) {
                    let strTag2:string = (curData[this.mainStateFields[1]])?`${strTag}__${(j == 0) ? curData[this.mainStateFields[1]] : ""}`:strTag;
                    if (this.mainStateFields.length >= 3) {
                        for (let k = 0; k <= 1; k++) {
                            let strTag3:string = (curData[this.mainStateFields[2]])?`${strTag2}__${(k == 0) ? curData[this.mainStateFields[2]] : ""}`:strTag2;
                            // 判断是否存在
                            return this.allDeMainStateMap.get(strTag3);
                        }
                    }else{
                        return this.allDeMainStateMap.get(strTag2);
                    }
                }
            }else{
                return this.allDeMainStateMap.get(strTag);
            }
        }
        return null;
    }

}